#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.glade_resources"), aligned (sizeof(void *) > 8 ? sizeof(void *) : 8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[8937]; const double alignment; void * const ptr;}  glade_resources_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\254\000\000\000\000\000\000\050\005\000\000\000"
  "\000\000\000\000\003\000\000\000\003\000\000\000\003\000\000\000"
  "\004\000\000\000\233\376\261\263\003\000\000\000\254\000\000\000"
  "\023\000\166\000\300\000\000\000\217\003\000\000\113\120\220\013"
  "\002\000\000\000\217\003\000\000\004\000\114\000\224\003\000\000"
  "\230\003\000\000\324\265\002\000\377\377\377\377\230\003\000\000"
  "\001\000\114\000\234\003\000\000\240\003\000\000\150\201\033\116"
  "\001\000\000\000\240\003\000\000\006\000\114\000\250\003\000\000"
  "\260\003\000\000\302\204\106\344\003\000\000\000\260\003\000\000"
  "\010\000\166\000\270\003\000\000\350\042\000\000\164\151\154\144"
  "\141\055\163\145\141\162\143\150\055\142\157\170\056\165\151\000"
  "\116\023\000\000\001\000\000\000\170\332\355\230\135\117\333\060"
  "\024\206\357\371\025\236\167\271\365\013\266\151\110\111\220\100"
  "\203\233\155\102\033\273\216\034\347\044\361\160\355\314\076\051"
  "\345\337\357\244\151\241\254\201\066\335\200\251\102\271\261\235"
  "\363\306\307\171\237\143\305\011\216\246\143\315\046\340\274\262"
  "\046\344\243\376\220\063\060\322\246\312\344\041\377\161\161\332"
  "\373\310\217\242\275\340\125\257\307\316\300\200\023\010\051\273"
  "\122\130\260\134\213\024\330\101\177\164\330\037\262\136\217\202"
  "\224\101\160\231\220\020\355\061\026\070\370\125\051\007\236\151"
  "\225\204\074\307\313\067\374\166\042\222\175\340\203\131\034\302"
  "\270\324\364\130\046\265\360\076\344\027\112\247\342\073\010\047"
  "\213\143\073\345\254\024\016\014\206\374\014\057\353\176\255\041"
  "\125\351\154\011\016\257\231\021\143\010\371\104\171\225\150\340"
  "\321\205\253\040\030\054\356\266\007\113\141\342\314\312\312\363"
  "\350\124\150\277\066\336\072\105\031\010\244\314\171\104\113\100"
  "\045\205\136\021\311\202\022\157\332\324\263\311\117\220\270\130"
  "\023\345\376\131\044\240\071\123\151\310\365\254\271\010\355\236"
  "\137\233\306\330\330\027\366\052\026\132\267\277\204\066\321\130"
  "\270\134\231\030\155\311\243\367\035\004\211\105\264\343\015\065"
  "\315\152\031\072\141\074\371\054\310\246\220\137\003\055\256\061"
  "\231\021\064\143\146\054\262\314\126\046\175\313\174\063\054\162"
  "\241\014\103\313\244\065\250\114\005\014\013\270\271\211\263\136"
  "\002\224\216\041\126\373\255\231\010\104\247\222\012\301\337\016"
  "\056\017\317\063\314\254\203\334\325\223\023\241\102\127\064\364"
  "\032\062\310\366\017\233\253\001\165\056\036\254\076\064\030\064"
  "\156\337\364\113\041\057\051\251\373\337\011\114\113\101\263\155"
  "\156\157\246\272\370\132\132\257\032\132\207\253\341\064\262\234"
  "\136\060\130\002\167\035\304\263\202\254\021\156\154\040\020\246"
  "\017\160\374\140\121\376\053\360\347\110\152\310\260\033\304\116"
  "\345\105\107\311\343\026\212\047\137\310\026\036\215\206\255\341"
  "\167\274\151\367\347\223\101\167\335\070\004\263\346\162\370\026"
  "\006\255\061\251\213\254\130\060\177\277\350\317\072\152\257\245"
  "\255\352\251\173\115\165\256\253\226\332\132\251\257\115\175\074"
  "\256\210\033\323\030\231\314\332\261\201\051\256\261\363\376\235"
  "\066\376\112\352\115\127\371\224\124\070\220\240\046\340\343\024"
  "\062\121\151\354\246\246\315\132\345\344\206\204\372\313\143\123"
  "\125\345\041\246\275\036\234\126\006\166\204\307\321\223\363\130"
  "\072\230\154\317\343\071\251\137\170\334\135\036\367\037\227\307"
  "\223\002\344\035\050\145\075\020\217\005\322\107\211\024\036\266"
  "\047\363\113\375\014\166\042\066\177\117\317\313\147\047\113\213"
  "\307\005\164\125\072\235\117\070\334\124\220\072\161\025\053\223"
  "\322\021\013\255\333\221\152\070\170\226\152\240\103\015\114\267"
  "\057\204\157\265\174\007\153\340\205\346\277\244\371\335\266\064"
  "\377\307\347\344\121\227\163\162\060\130\374\263\212\366\202\301"
  "\322\137\257\337\172\122\353\225\000\050\165\165\141\171\051\157"
  "\162\147\057\000\003\000\000\000\057\000\000\000\001\000\000\000"
  "\164\151\154\144\141\057\000\000\000\000\000\000\004\000\000\000"
  "\164\151\154\144\141\056\165\151\075\277\002\000\001\000\000\000"
  "\170\332\355\135\131\163\343\070\222\176\237\137\201\325\303\364"
  "\314\354\272\254\323\166\325\124\173\302\127\165\125\164\135\121"
  "\162\115\355\356\013\003\042\041\011\143\210\340\220\224\145\125"
  "\314\177\330\307\375\177\373\113\026\000\251\303\026\111\361\222"
  "\104\102\031\035\121\155\112\142\342\312\114\344\361\041\361\366"
  "\157\117\023\206\036\211\353\121\156\377\332\150\275\152\066\020"
  "\261\115\156\121\173\364\153\343\373\375\273\223\213\306\337\056"
  "\377\360\366\337\116\116\320\157\304\046\056\366\211\205\146\324"
  "\037\243\021\303\026\101\235\127\355\366\253\066\072\071\021\077"
  "\242\266\117\334\041\066\311\345\037\020\172\353\222\177\116\251"
  "\113\074\304\350\340\327\306\310\177\370\367\306\252\241\316\253"
  "\126\263\161\252\176\307\007\377\040\246\217\114\206\075\357\327"
  "\306\157\376\303\225\365\217\251\347\117\210\355\067\020\265\176"
  "\155\340\345\163\253\041\337\020\357\070\056\167\210\353\317\221"
  "\215\047\344\327\306\324\021\117\215\313\126\263\371\366\164\361"
  "\125\364\057\075\237\070\006\265\115\227\050\372\227\255\155\057"
  "\070\170\104\236\275\360\242\211\267\247\101\377\063\017\245\231"
  "\074\226\166\253\173\336\275\350\234\165\317\353\063\044\215\226"
  "\247\255\317\120\072\372\014\245\253\317\120\172\372\014\345\114"
  "\237\241\234\353\063\224\013\175\206\362\072\146\050\214\317\324"
  "\120\266\365\053\363\226\372\210\331\224\244\040\274\347\031\372"
  "\110\075\277\357\163\227\004\023\304\304\243\047\037\227\373\256"
  "\311\331\164\142\173\301\223\170\226\126\133\360\331\211\154\037"
  "\215\314\061\166\261\353\342\171\113\131\154\341\317\202\237\040"
  "\177\356\210\056\256\176\023\330\147\262\123\317\350\276\265\260"
  "\217\227\357\272\174\266\370\073\240\244\272\046\254\110\337\305"
  "\266\307\304\117\007\114\120\235\023\257\161\171\303\270\107\320"
  "\075\145\026\126\064\227\104\116\327\250\144\242\370\305\041\066"
  "\302\310\046\063\044\114\317\011\265\061\333\035\145\204\155\013"
  "\215\251\105\342\232\170\173\272\230\232\114\353\070\341\026\141"
  "\071\326\360\020\113\170\317\235\222\046\370\232\373\076\237\224"
  "\104\354\043\031\372\045\221\372\106\107\343\262\150\275\247\226"
  "\105\354\235\260\113\263\036\374\362\216\233\123\017\335\227\053"
  "\233\142\132\311\126\232\205\146\267\046\322\170\315\270\371\200"
  "\156\246\256\307\335\222\346\366\303\065\301\223\162\111\176\267"
  "\055\342\062\152\223\055\144\013\255\130\273\036\053\326\037\363"
  "\031\232\215\071\043\110\174\214\174\352\063\122\322\064\053\322"
  "\103\352\172\076\262\221\034\201\207\370\260\374\026\304\062\244"
  "\157\240\310\222\326\144\105\077\170\366\057\076\262\250\347\060"
  "\074\047\126\111\123\375\033\047\036\302\103\141\172\040\152\123"
  "\237\012\353\243\314\225\124\344\007\144\050\146\174\047\364\277"
  "\021\061\033\146\112\332\105\230\244\123\017\046\271\025\066\076"
  "\362\071\362\307\004\131\144\210\247\314\107\336\230\060\126\332"
  "\174\173\076\166\175\105\337\344\223\211\260\124\113\242\174\367"
  "\104\003\262\376\016\367\333\056\030\277\065\060\176\213\254\160"
  "\257\036\053\174\063\365\312\133\227\337\134\042\174\110\156\243"
  "\153\241\013\037\312\342\034\111\113\022\375\061\246\176\131\352"
  "\132\321\052\273\247\377\115\354\301\324\265\313\262\075\070\303"
  "\056\375\111\054\364\261\104\007\155\105\365\026\273\145\015\274"
  "\157\343\237\077\347\273\220\242\063\035\244\250\310\004\234\327"
  "\143\002\276\330\152\313\054\121\061\207\024\313\014\116\334\122"
  "\117\076\131\273\130\247\213\172\254\323\125\377\346\303\007\164"
  "\173\367\261\054\143\311\063\261\103\220\107\376\071\045\266\131"
  "\226\166\276\341\266\357\162\166\362\176\027\053\365\032\126\252"
  "\016\053\045\374\050\356\032\062\342\157\250\220\177\332\125\133"
  "\274\351\260\351\310\120\237\244\137\274\010\162\366\164\062\020"
  "\056\151\054\015\152\373\011\157\207\116\162\326\176\074\143\242"
  "\344\171\273\025\316\046\037\005\223\066\243\077\261\153\031\063"
  "\152\133\174\026\223\101\062\261\155\014\145\210\262\161\371\016"
  "\063\217\154\313\337\014\270\153\021\127\320\264\374\161\343\262"
  "\267\355\347\312\355\215\166\045\144\022\004\011\176\031\322\321"
  "\066\052\301\010\014\207\173\302\231\346\166\343\322\044\022\150"
  "\263\265\161\061\235\306\130\256\310\245\315\335\211\364\334\136"
  "\274\340\321\221\114\153\004\077\267\204\013\351\362\171\003\215"
  "\205\363\310\210\053\006\073\025\116\212\155\204\363\150\312\344"
  "\215\370\227\232\017\104\074\015\032\310\233\141\307\041\142\246"
  "\155\276\134\052\163\054\006\026\256\244\032\375\000\273\215\345"
  "\102\253\240\300\230\063\061\207\253\265\225\157\074\173\133\301"
  "\210\104\307\116\324\343\257\215\307\001\177\132\321\330\130\363"
  "\153\361\255\132\160\113\055\376\211\374\171\253\261\046\263\057"
  "\223\173\324\243\142\041\304\032\270\323\215\005\317\303\044\121"
  "\357\220\107\261\106\322\007\270\375\335\370\372\345\303\347\373"
  "\273\157\306\247\057\367\037\276\174\066\076\135\365\177\107\377"
  "\102\021\337\274\027\117\353\137\137\177\277\277\027\037\177\375"
  "\166\327\357\107\174\376\355\356\343\335\125\377\116\175\223\246"
  "\117\334\245\242\123\070\340\241\107\361\005\065\067\231\042\062"
  "\315\351\140\223\332\243\306\145\073\362\327\321\253\206\115\331"
  "\220\201\135\202\327\026\043\162\001\025\237\275\134\306\265\367"
  "\133\317\010\344\130\321\274\253\132\325\225\215\114\206\343\071"
  "\237\312\335\141\056\147\202\310\000\120\314\213\153\022\267\116"
  "\156\103\066\227\137\235\106\274\021\103\045\146\161\203\225\215"
  "\120\050\215\227\024\242\006\066\040\254\161\071\362\037\116\324"
  "\053\161\343\312\315\031\105\270\043\352\135\227\230\204\076\022"
  "\317\010\043\175\071\110\114\205\252\025\373\274\371\220\242\347"
  "\317\264\170\250\237\213\151\361\365\245\137\355\266\317\373\213"
  "\315\007\241\022\266\217\204\074\071\242\047\071\246\140\110\031"
  "\313\276\156\253\115\262\025\377\232\370\046\252\373\021\174\036"
  "\065\376\350\261\347\032\167\366\061\157\002\112\314\007\103\156"
  "\267\311\042\037\073\113\315\350\127\042\146\150\143\166\066\065"
  "\300\246\364\177\346\076\031\160\376\360\314\042\263\027\037\036"
  "\122\253\247\124\137\277\271\324\012\072\077\022\177\031\043\005"
  "\201\146\215\212\152\236\300\116\066\306\174\302\145\117\271\044"
  "\262\265\375\310\231\210\236\215\167\256\150\046\230\216\241\374"
  "\063\064\256\215\320\260\157\104\121\051\060\065\105\247\047\352"
  "\375\011\166\205\227\142\060\062\364\043\014\370\224\157\273\062"
  "\014\223\377\165\237\073\371\137\036\250\324\101\216\367\307\013"
  "\225\224\147\332\325\046\154\074\141\046\066\233\130\255\221\206"
  "\251\242\031\353\112\322\135\203\376\055\036\133\215\070\032\005"
  "\331\252\014\326\052\316\136\045\260\130\141\066\213\134\155\321"
  "\175\303\301\226\245\254\376\126\073\025\215\304\045\117\245\135"
  "\123\151\223\322\226\277\054\026\110\120\304\113\307\251\127\220"
  "\120\046\215\236\155\125\242\127\346\146\114\314\147\266\273\051"
  "\077\060\124\226\331\360\145\360\302\030\053\160\133\143\033\355"
  "\070\203\076\062\163\242\222\330\101\154\144\034\142\347\322\215"
  "\263\064\216\330\302\025\105\111\345\360\015\266\221\114\255\224"
  "\223\210\130\056\236\031\102\374\250\211\175\356\146\035\147\234"
  "\233\260\331\152\234\333\220\112\043\141\337\307\346\070\321\264"
  "\337\116\111\150\305\074\204\142\174\206\315\237\245\020\270\222"
  "\205\022\263\031\236\173\006\017\065\176\211\362\170\245\050\313"
  "\304\260\057\241\017\040\212\040\212\273\022\305\246\026\242\270"
  "\310\160\310\300\045\143\306\214\273\017\322\006\220\262\124\242"
  "\130\336\006\255\110\271\024\255\240\125\053\040\242\040\242\033"
  "\042\332\054\113\104\273\172\210\050\227\001\050\303\033\163\271"
  "\204\206\217\275\207\365\034\125\051\362\311\221\150\002\311\046"
  "\020\025\173\147\320\004\010\047\010\347\356\204\123\017\123\126"
  "\111\345\042\076\154\004\331\366\162\075\114\051\223\213\250\064"
  "\272\126\015\200\140\202\140\356\116\060\365\060\154\075\042\246"
  "\106\162\224\367\120\266\223\331\047\076\302\036\272\015\110\243"
  "\040\010\130\144\366\145\362\164\201\036\160\034\202\105\223\046"
  "\051\101\010\100\326\301\211\075\006\013\071\010\362\016\247\214"
  "\171\246\074\302\260\203\020\257\260\212\127\364\101\046\101\046"
  "\167\267\377\266\353\045\223\175\342\210\015\113\256\217\222\110"
  "\157\361\330\152\124\103\070\012\263\162\346\344\144\131\371\360"
  "\372\263\162\247\010\241\020\263\134\063\161\370\030\154\044\252"
  "\334\315\200\011\327\060\144\104\303\021\333\207\061\165\214\001"
  "\031\343\107\312\247\256\056\362\021\277\165\176\346\366\211\152"
  "\005\175\025\203\107\337\035\164\275\030\374\233\042\055\022\306"
  "\250\343\321\237\311\030\262\324\074\146\250\322\000\005\331\176"
  "\261\341\265\364\227\352\263\232\031\215\174\062\340\113\260\266"
  "\051\237\216\101\054\325\141\251\306\145\130\174\047\023\245\124"
  "\023\035\063\331\102\066\277\021\131\077\205\270\367\344\051\204"
  "\107\271\341\047\255\326\046\142\067\222\256\140\065\227\016\246"
  "\076\361\322\374\174\375\205\005\277\312\266\045\313\057\277\110"
  "\325\356\151\226\206\123\161\155\175\175\303\063\075\354\320\066"
  "\330\241\107\157\207\366\264\267\103\343\017\303\344\150\165\373"
  "\062\157\041\222\114\040\361\345\147\007\362\302\223\064\251\121"
  "\271\353\306\267\374\263\123\067\064\156\274\055\375\107\346\377"
  "\165\360\307\221\377\327\037\052\334\214\102\110\205\374\370\124"
  "\175\236\247\071\031\170\026\332\340\141\352\244\035\166\356\225"
  "\115\172\061\131\135\024\123\021\005\062\035\011\142\034\073\320"
  "\102\207\023\026\025\213\340\170\002\034\117\310\262\013\244\077"
  "\236\320\206\343\011\207\070\236\220\307\342\252\310\021\207\224"
  "\072\251\124\113\172\127\207\034\134\076\133\235\160\350\226\165"
  "\124\242\253\311\121\011\123\325\072\065\006\214\332\017\345\302"
  "\077\203\052\252\350\132\121\206\344\031\044\317\000\225\235\054"
  "\212\113\245\053\044\212\225\173\100\142\152\111\011\132\026\243"
  "\106\327\252\246\047\210\044\210\044\340\311\042\143\010\306\243"
  "\117\026\173\243\067\306\016\321\077\157\027\356\327\175\071\332"
  "\067\010\062\165\200\261\076\104\246\116\127\271\173\226\230\153"
  "\125\044\061\167\016\211\271\332\330\270\007\221\152\155\162\002"
  "\135\015\163\002\113\153\036\262\002\305\263\002\255\212\145\005"
  "\206\134\126\304\204\114\000\144\002\312\314\004\164\040\023\000"
  "\231\200\114\231\200\004\075\124\277\350\177\357\150\013\045\155"
  "\304\067\122\254\253\006\061\215\167\142\224\157\040\154\240\143"
  "\304\116\056\155\104\325\336\012\361\165\371\001\355\242\024\203"
  "\311\351\013\061\101\255\166\021\102\216\113\036\051\231\031\312"
  "\257\077\315\376\276\072\100\277\040\042\354\022\167\236\131\015"
  "\100\256\352\030\375\370\236\206\176\274\324\144\340\273\027\360"
  "\335\333\025\363\335\303\002\241\170\352\163\131\176\222\200\037"
  "\017\176\174\311\176\074\070\362\340\310\147\163\344\361\324\112"
  "\324\106\265\361\346\363\373\316\025\361\305\373\016\265\327\075"
  "\027\117\074\257\066\013\303\247\023\242\211\007\103\355\260\127"
  "\052\205\337\270\374\277\377\375\237\042\344\260\365\217\251\347"
  "\053\165\170\271\372\273\005\076\103\325\062\372\061\005\200\227"
  "\054\056\374\364\011\227\106\053\043\370\221\224\012\165\173\057"
  "\350\207\245\271\147\143\142\043\325\016\122\355\170\210\372\000"
  "\172\113\035\362\002\034\252\356\310\233\227\316\165\133\233\123"
  "\263\302\242\027\006\175\253\271\233\250\362\225\120\144\110\051"
  "\232\133\302\360\034\002\314\107\273\213\005\325\044\030\367\374"
  "\362\067\061\265\175\005\073\231\274\015\315\103\252\061\330\300"
  "\140\003\323\014\072\252\115\160\272\335\324\060\072\275\334\354"
  "\040\104\135\040\104\335\251\130\210\132\164\146\044\376\060\310"
  "\023\005\230\031\204\247\113\016\117\267\273\020\236\206\360\164"
  "\226\360\164\013\256\321\253\020\072\254\175\246\077\064\354\207"
  "\164\257\304\014\370\150\161\356\026\121\017\251\213\247\055\360"
  "\350\365\364\350\043\152\102\012\047\136\062\301\352\360\165\202"
  "\105\124\073\356\017\017\235\061\352\371\236\360\142\111\125\316"
  "\235\065\341\334\031\344\236\366\032\265\023\103\230\070\276\224"
  "\366\234\362\275\365\366\311\240\005\171\331\235\154\001\302\164"
  "\020\246\073\326\074\023\124\245\214\262\251\133\072\102\127\277"
  "\006\141\044\164\047\124\036\304\007\013\304\007\273\207\215\017"
  "\156\034\017\162\211\272\136\107\136\020\111\315\132\000\130\013"
  "\305\311\036\213\274\034\044\233\063\007\366\346\371\136\113\226"
  "\112\157\202\031\223\062\050\037\350\342\017\045\225\362\072\301"
  "\067\053\041\105\175\076\041\210\073\362\002\062\017\271\344\237"
  "\123\352\022\344\217\261\160\210\125\322\221\312\117\025\027\020"
  "\353\225\172\157\111\357\164\331\114\326\336\147\025\363\227\357"
  "\113\320\027\035\316\033\227\046\261\375\355\167\042\346\266\071"
  "\066\026\053\235\123\137\105\325\322\053\133\265\104\017\062\362"
  "\307\317\166\120\301\253\033\212\044\121\025\331\003\043\320\106"
  "\062\030\346\342\250\335\067\267\012\052\242\176\322\213\344\157"
  "\101\307\343\211\305\061\114\074\263\154\054\065\036\030\103\052"
  "\013\306\155\351\167\314\102\047\254\333\366\305\172\131\066\224"
  "\372\214\030\102\221\032\046\237\114\224\102\255\346\212\075\013"
  "\367\167\163\274\031\206\371\363\274\252\302\373\171\136\134\204"
  "\365\063\275\233\276\372\151\031\301\350\142\307\146\270\153\055"
  "\152\175\125\337\336\040\217\142\007\222\042\176\373\273\361\365"
  "\313\207\317\367\167\337\214\117\137\356\077\174\371\154\174\272"
  "\352\377\216\376\205\042\276\171\057\236\326\277\276\376\176\177"
  "\057\076\376\372\355\256\337\217\370\374\333\335\307\273\253\376"
  "\235\372\246\046\251\277\372\271\071\125\133\310\352\044\345\014"
  "\217\060\361\275\061\230\053\331\254\163\212\256\212\213\134\154"
  "\143\052\151\223\052\145\303\052\153\363\052\147\043\313\222\252"
  "\355\326\076\125\333\321\045\131\125\125\021\315\230\126\026\212"
  "\022\335\010\043\006\233\302\077\365\040\223\254\145\226\351\116"
  "\225\254\120\122\250\252\127\154\267\135\353\226\360\251\256\064"
  "\102\042\365\030\323\047\365\203\024\326\302\257\330\236\342\351"
  "\053\037\000\015\346\110\156\155\220\344\321\010\004\076\165\031"
  "\104\132\352\033\151\151\203\106\324\046\322\042\104\321\030\143"
  "\333\142\252\131\210\263\100\234\005\342\054\125\274\056\155\202"
  "\175\163\154\330\323\311\200\270\345\136\227\366\111\122\106\237"
  "\003\312\000\037\334\017\174\020\233\076\175\054\141\252\216\363"
  "\264\360\231\026\320\340\100\244\311\004\123\146\210\175\337\045"
  "\236\107\166\041\332\167\262\005\164\265\150\001\104\034\020\302"
  "\273\023\315\236\106\242\071\244\114\372\252\164\027\102\371\116"
  "\320\106\337\277\175\000\161\204\035\267\006\142\335\255\173\232"
  "\204\014\214\201\360\060\074\342\102\236\004\362\044\171\242\244"
  "\125\343\361\015\350\174\365\170\034\122\363\101\152\236\014\320"
  "\165\260\060\350\057\220\230\327\122\032\343\156\271\347\142\373"
  "\341\302\277\223\326\007\366\205\131\244\114\313\122\015\312\257"
  "\322\257\103\330\266\220\074\373\206\156\356\277\175\104\076\107"
  "\213\046\221\152\021\314\114\360\372\000\105\263\105\130\247\236"
  "\317\047\005\367\321\170\071\375\356\021\024\064\201\104\023\050"
  "\154\002\205\047\026\100\100\263\345\116\332\115\220\365\203\310"
  "\172\133\243\010\217\024\365\035\005\170\244\321\007\361\035\210"
  "\357\324\103\250\217\250\260\003\264\012\255\102\231\220\315\062"
  "\041\027\200\352\072\010\316\065\060\027\336\207\030\054\300\271"
  "\152\164\037\237\072\226\136\007\244\353\201\220\244\265\203\326"
  "\037\010\244\231\304\107\245\372\016\273\102\147\002\352\061\326"
  "\235\002\324\143\144\062\213\332\324\247\230\245\142\375\332\244"
  "\263\342\255\201\017\301\160\321\275\034\056\244\210\264\214\072"
  "\157\200\022\252\304\333\307\121\277\262\131\363\024\177\120\347"
  "\150\202\237\304\126\152\217\374\261\376\212\121\051\104\364\011"
  "\077\241\217\152\304\240\033\265\114\237\107\136\115\133\121\156"
  "\257\307\345\264\055\000\154\125\055\023\025\161\013\200\065\027"
  "\303\242\046\146\154\156\170\304\257\261\111\020\173\011\200\372"
  "\137\273\032\027\000\264\241\376\177\155\244\273\346\167\332\276"
  "\024\155\375\115\265\333\325\200\117\304\200\301\227\075\046\156"
  "\017\154\265\001\031\343\107\312\247\356\261\070\046\327\213\001"
  "\003\237\227\222\242\251\203\315\246\051\253\257\233\153\255\212"
  "\330\153\255\013\060\330\152\143\260\265\241\316\130\001\374\305"
  "\231\206\267\264\250\075\022\020\015\005\020\015\315\212\041\032"
  "\342\313\353\003\246\041\170\354\001\246\041\025\246\041\231\223"
  "\000\325\000\250\206\362\120\015\262\073\371\041\015\125\051\014"
  "\025\341\212\204\102\124\245\273\143\313\214\032\167\252\341\205"
  "\164\300\011\001\047\144\117\230\220\360\014\142\272\335\021\300"
  "\041\107\234\160\210\071\330\346\116\355\342\114\024\357\333\175"
  "\233\332\010\057\216\261\206\015\040\152\173\076\301\026\342\103"
  "\344\217\011\362\306\102\235\126\355\334\133\341\370\030\234\070"
  "\007\354\137\171\371\222\112\352\371\035\246\113\156\002\215\161"
  "\023\214\027\262\045\307\221\025\254\240\177\262\103\036\377\061"
  "\046\366\202\303\325\315\324\160\013\217\246\131\301\270\142\077"
  "\001\267\063\056\203\050\312\012\052\275\200\010\106\212\172\065"
  "\155\054\050\352\243\223\120\166\240\046\300\156\133\325\046\167"
  "\171\256\141\356\062\334\307\041\173\131\040\173\331\072\154\366"
  "\262\157\272\234\061\142\375\020\252\233\317\302\203\005\341\147"
  "\063\365\131\153\317\211\314\074\257\217\311\223\243\134\304\134"
  "\131\320\307\305\333\171\232\366\306\130\114\222\041\225\104\343"
  "\222\332\145\247\120\377\116\311\314\341\156\030\155\177\014\237"
  "\132\165\123\046\317\146\311\346\066\331\125\006\165\303\275\012"
  "\113\310\011\323\144\310\353\234\110\315\304\244\331\165\372\137"
  "\320\025\172\024\166\240\265\014\130\372\143\054\046\026\333\110"
  "\120\220\361\314\105\055\276\311\324\363\321\200\040\142\373\304"
  "\045\026\032\213\177\137\241\017\076\242\036\162\270\247\246\114"
  "\326\326\024\172\135\105\072\145\313\062\352\211\221\347\020\223"
  "\016\251\271\044\345\115\315\061\302\036\372\145\110\135\062\344"
  "\117\277\250\012\235\277\214\070\037\061\162\142\216\135\076\041"
  "\277\040\356\256\223\223\371\104\127\320\010\273\051\136\176\072"
  "\231\315\146\047\041\315\220\304\223\065\072\221\375\376\345\025"
  "\272\027\057\015\210\350\363\142\140\023\074\227\375\267\350\160"
  "\050\272\156\373\310\042\342\227\062\265\217\270\035\004\147\347"
  "\236\117\046\257\362\316\362\314\305\116\261\165\312\154\221\277"
  "\044\060\317\106\340\160\126\126\025\267\344\136\325\000\105\214"
  "\013\033\111\110\053\100\212\342\057\334\153\001\246\050\035\246"
  "\150\013\063\001\252\010\120\105\332\336\020\147\162\133\230\032"
  "\223\324\102\220\315\206\352\217\371\014\205\115\140\237\012\143"
  "\302\242\230\361\021\232\311\240\267\154\123\332\030\342\015\210"
  "\111\102\114\122\263\264\257\076\065\036\365\211\323\335\110\055"
  "\207\256\114\251\212\122\121\116\207\221\333\200\344\315\210\332"
  "\101\245\377\070\025\217\003\316\254\044\064\140\032\054\236\126"
  "\376\104\267\154\177\042\156\220\361\003\174\331\075\341\250\123"
  "\311\026\211\361\307\230\216\105\166\352\231\014\106\155\254\211"
  "\222\147\017\214\365\043\262\062\101\030\217\372\310\055\205\105"
  "\244\057\353\241\127\031\150\270\331\166\153\301\236\326\061\202"
  "\073\361\100\336\334\307\266\016\074\073\013\154\137\367\027\016"
  "\011\166\034\202\305\064\232\244\252\153\235\336\333\050\340\141"
  "\344\366\052\266\170\022\275\054\357\246\367\036\012\171\014\145"
  "\170\011\205\042\052\343\140\307\202\160\112\134\070\345\014\242"
  "\051\251\224\127\042\043\101\050\005\102\051\160\100\053\071\075"
  "\027\010\220\041\232\064\205\332\301\243\043\250\143\373\165\071"
  "\126\100\076\126\067\240\121\162\235\306\252\362\171\121\122\321"
  "\225\025\333\205\242\166\164\104\345\235\025\155\250\265\133\061"
  "\316\216\325\336\364\211\060\357\030\052\220\243\257\152\250\172"
  "\053\356\066\050\356\115\305\135\045\026\337\215\322\356\124\226"
  "\041\073\220\032\251\102\152\344\102\103\010\363\173\045\336\200"
  "\140\256\057\202\171\043\270\347\021\046\176\141\114\270\115\125"
  "\326\027\202\174\061\101\276\316\005\104\371\322\104\371\332\020"
  "\337\203\370\036\304\367\362\230\014\355\327\372\173\205\237\202"
  "\215\006\316\061\153\351\024\106\226\024\033\163\211\037\114\266"
  "\060\152\307\341\313\252\142\152\124\006\243\236\157\170\342\057"
  "\162\330\012\143\246\370\164\121\145\114\026\377\152\065\122\126"
  "\016\173\051\142\302\156\020\002\326\313\062\232\364\122\226\001"
  "\077\225\200\244\132\170\021\155\050\157\166\264\101\325\116\263"
  "\236\012\005\142\102\207\141\227\026\260\213\366\061\155\155\102"
  "\210\155\035\143\210\175\025\160\102\241\341\004\261\104\215\152"
  "\271\317\250\025\173\247\042\204\020\155\377\034\042\210\151\042"
  "\210\211\174\004\141\104\010\043\102\030\061\031\150\242\344\007"
  "\120\202\020\127\324\027\113\025\262\070\100\251\164\342\156\200"
  "\122\255\101\251\052\252\304\167\203\246\352\002\004\366\330\030"
  "\133\177\210\140\017\302\301\020\337\113\262\142\136\153\030\336"
  "\373\041\245\033\242\172\005\242\172\355\212\105\365\126\247\346"
  "\041\260\027\023\330\003\150\140\272\300\336\026\126\202\330\136"
  "\255\143\173\331\352\012\307\056\166\051\124\040\316\130\276\065"
  "\037\127\046\056\254\155\053\072\344\322\237\134\070\253\214\315"
  "\113\055\025\167\263\250\236\373\176\255\005\270\016\054\175\310"
  "\247\120\330\020\233\276\350\126\361\271\052\126\137\116\320\363"
  "\304\130\060\133\132\114\243\021\043\142\163\031\013\145\301\210"
  "\233\310\215\106\370\153\303\034\064\220\067\223\105\164\144\035"
  "\045\276\375\032\116\210\357\036\046\276\073\117\153\053\150\020"
  "\335\375\057\364\065\034\053\204\167\123\061\167\113\203\050\330"
  "\123\325\030\174\067\061\260\063\270\345\265\016\334\070\077\016"
  "\156\074\327\077\042\133\367\013\036\237\216\150\343\377\317\043"
  "\331\370\233\160\241\166\244\303\374\050\006\042\274\241\235\271"
  "\313\177\137\322\007\147\031\234\345\044\147\171\305\211\265\161"
  "\225\217\004\054\002\267\122\126\250\332\175\123\303\204\355\302"
  "\004\201\234\155\201\234\155\247\142\071\133\261\322\036\344\153"
  "\143\363\265\257\041\137\233\052\137\233\300\106\220\253\205\134"
  "\055\344\152\053\233\253\335\210\253\310\113\054\034\176\004\130"
  "\371\205\075\043\157\121\275\027\372\013\052\315\150\231\061\214"
  "\252\064\243\031\217\057\113\314\210\377\265\016\133\126\146\121"
  "\122\246\265\075\014\240\310\026\256\355\042\153\327\050\236\204"
  "\312\056\307\042\320\321\301\322\300\302\110\143\211\146\333\046"
  "\356\024\135\265\103\100\160\164\117\301\321\343\274\141\122\217"
  "\244\205\067\226\126\272\350\032\333\321\125\260\001\155\051\220"
  "\040\217\040\217\200\327\110\043\217\301\005\220\076\347\314\247"
  "\116\251\042\171\113\075\207\341\071\012\356\147\244\066\272\017"
  "\032\201\313\230\101\064\167\267\125\266\265\020\115\152\173\142"
  "\004\312\033\305\103\237\270\206\071\165\135\205\104\052\265\044"
  "\200\154\004\175\046\063\145\303\042\325\022\272\011\132\252\342"
  "\056\012\222\252\323\046\332\206\203\277\005\022\311\335\236\206"
  "\211\144\251\206\040\211\134\245\233\317\013\046\221\311\223\130"
  "\156\110\043\307\247\221\153\210\007\071\114\036\071\221\223\040"
  "\223\014\231\144\310\044\127\066\223\034\171\136\204\221\107\241"
  "\160\371\320\120\006\201\203\205\323\141\316\265\076\072\162\001"
  "\125\323\052\346\175\157\100\034\260\115\047\130\246\376\205\213"
  "\310\360\134\177\250\303\325\142\300\350\126\016\030\375\111\030"
  "\320\346\237\365\306\073\264\340\240\324\113\156\347\056\225\045"
  "\002\217\343\314\324\212\347\277\254\206\015\054\257\143\170\065"
  "\322\362\250\246\222\337\215\315\361\032\216\362\127\055\342\037"
  "\201\072\323\132\021\257\143\320\272\325\300\240\165\001\203\126"
  "\033\361\326\043\241\027\110\070\261\014\147\312\230\305\147\166"
  "\243\174\213\206\130\350\153\110\035\360\057\220\272\003\074\132"
  "\254\343\123\345\330\323\016\035\237\217\162\330\352\120\303\332"
  "\260\301\361\321\061\262\025\007\205\266\045\073\024\145\373\004"
  "\110\264\242\137\032\177\301\126\004\133\021\202\322\013\272\141"
  "\127\132\055\015\261\053\167\052\101\015\350\225\002\350\225\136"
  "\331\350\225\270\101\306\017\360\145\367\126\225\304\022\374\320"
  "\230\216\105\166\352\231\040\105\235\202\110\024\037\173\140\204"
  "\241\173\307\041\130\160\243\031\165\251\117\156\021\052\042\072"
  "\031\274\325\145\337\223\246\164\057\053\027\301\217\170\140\014"
  "\051\143\133\107\234\175\321\267\257\364\013\314\213\311\031\167"
  "\275\252\056\160\172\074\113\001\014\113\156\334\112\021\254\112"
  "\176\144\111\176\064\111\041\004\111\031\100\217\102\070\277\130"
  "\116\055\274\243\327\014\347\367\102\202\207\203\344\251\251\254"
  "\301\223\035\254\126\002\120\255\060\110\255\014\200\132\161\160"
  "\132\161\140\132\161\120\132\051\200\264\062\361\143\171\040\240"
  "\175\342\010\073\101\072\263\112\242\306\336\342\271\125\037\034"
  "\150\032\277\072\235\117\135\216\077\135\112\130\367\045\221\360"
  "\266\355\166\332\051\331\072\336\255\336\160\036\166\212\312\274"
  "\006\332\331\034\223\011\251\067\270\170\055\311\332\333\371\055"
  "\056\211\311\325\136\212\072\237\231\362\233\305\223\252\351\023"
  "\252\245\204\141\112\221\350\126\031\022\335\254\266\104\156\044"
  "\146\314\251\353\161\067\220\312\072\213\143\102\145\145\065\102"
  "\164\043\107\230\227\172\306\264\113\235\266\240\156\325\267\020"
  "\261\154\317\322\052\362\203\201\372\040\144\336\003\263\155\021"
  "\062\005\063\033\033\344\106\003\334\270\024\377\376\251\371\037"
  "\342\277\077\127\212\133\133\307\316\255\301\056\012\274\172\054"
  "\274\332\256\061\257\016\104\227\200\127\217\207\127\073\065\063"
  "\133\245\056\325\331\150\225\116\036\230\254\365\124\254\033\314"
  "\052\225\351\310\345\123\333\322\231\145\257\227\243\004\306\325"
  "\104\313\016\246\224\371\324\326\224\137\345\340\116\250\215\372"
  "\101\060\022\370\365\160\301\254\312\340\244\332\032\342\244\336"
  "\161\227\204\212\131\126\317\175\251\247\001\101\125\004\101\325"
  "\254\130\375\037\007\063\342\373\004\200\001\057\201\001\311\023"
  "\003\260\200\312\303\002\352\233\324\057\301\024\353\166\353\154"
  "\204\125\251\334\120\362\206\351\115\060\143\162\053\224\017\164"
  "\361\207\332\034\077\163\237\274\131\355\225\350\236\270\023\052"
  "\257\153\304\216\303\344\021\000\312\155\017\215\361\043\101\376"
  "\230\170\004\005\231\156\204\037\061\145\352\220\206\317\345\067"
  "\223\127\212\310\222\370\351\262\315\274\103\312\276\005\107\323"
  "\221\107\330\351\160\336\270\014\256\230\314\215\115\160\161\301"
  "\216\144\074\235\241\241\111\135\167\304\307\012\244\020\240\076"
  "\302\335\327\010\200\037\265\322\145\073\201\154\234\001\144\243"
  "\062\261\357\126\265\105\052\332\216\335\216\162\255\076\202\252"
  "\112\025\021\053\126\205\360\120\205\003\023\223\202\013\326\153"
  "\165\033\120\236\074\126\261\250\053\027\302\144\377\315\230\363"
  "\205\045\210\132\275\102\204\345\245\016\321\000\247\240\221\233"
  "\240\221\156\145\117\240\236\035\155\375\241\064\062\325\001\231"
  "\312\043\123\335\175\310\124\247\262\062\325\003\231\112\220\251"
  "\036\310\124\036\231\072\333\207\114\365\052\053\123\347\040\123"
  "\011\062\325\006\231\312\043\123\235\175\310\124\273\262\062\325"
  "\005\231\112\220\251\046\310\124\036\231\152\355\103\246\232\120"
  "\317\265\226\062\325\002\231\312\043\123\355\175\310\124\165\253"
  "\327\165\100\246\342\145\352\065\210\124\036\221\152\356\101\244"
  "\136\303\335\017\165\224\250\163\220\250\034\022\165\261\007\201"
  "\072\327\077\074\321\324\120\240\316\100\240\162\010\324\371\036"
  "\004\352\114\377\274\224\216\002\005\041\364\074\002\265\217\010"
  "\172\117\377\244\224\216\002\005\330\211\074\002\265\017\350\104"
  "\127\377\350\271\216\002\005\300\211\074\002\265\017\334\104\107"
  "\377\060\237\216\002\005\031\336\074\002\265\217\004\157\033\356"
  "\063\256\145\056\012\004\052\207\100\355\045\023\005\327\050\325"
  "\121\240\000\057\221\053\021\265\007\201\052\224\353\312\127\146"
  "\353\000\302\331\004\341\214\027\316\013\020\316\034\302\371\172"
  "\017\302\171\001\367\144\356\104\240\240\050\145\116\055\223\130"
  "\367\040\324\047\047\334\221\047\353\047\304\236\236\044\227\367"
  "\051\121\265\034\260\032\125\130\032\377\115\221\142\000\123\171"
  "\310\230\121\233\124\242\036\300\304\046\023\156\123\323\230\121"
  "\153\104\204\342\213\072\022\016\245\002\352\166\056\171\243\104"
  "\111\107\323\372\361\152\357\014\271\125\043\261\324\130\162\052"
  "\276\311\135\311\211\027\033\132\130\023\002\057\036\133\035\015"
  "\013\143\354\371\102\126\050\366\231\326\227\213\276\257\172\040"
  "\126\312\240\236\061\010\353\205\225\244\104\373\143\076\103\222"
  "\066\222\276\017\022\166\116\320\100\130\044\051\167\111\050\175"
  "\153\216\147\276\241\272\274\333\251\241\160\171\346\111\331\137"
  "\211\322\166\117\303\022\245\137\003\353\012\052\221\026\250\104"
  "\332\252\362\135\316\235\112\335\345\134\355\153\176\267\270\042"
  "\336\176\356\160\356\324\365\016\147\317\164\071\143\252\374\022"
  "\134\343\174\330\153\234\217\345\062\346\044\226\053\274\055\327"
  "\273\354\362\162\152\214\040\216\133\357\173\231\323\035\217\205"
  "\012\314\305\025\102\051\212\241\220\177\034\161\167\155\300\314"
  "\003\354\032\253\175\362\330\253\062\257\337\203\173\176\330\242"
  "\252\347\120\124\025\356\301\315\347\125\077\027\355\132\113\165"
  "\270\261\013\231\050\077\027\322\137\314\022\242\151\063\224\160"
  "\337\315\256\103\266\324\036\122\233\372\144\311\303\231\257\156"
  "\214\137\360\217\164\102\175\264\042\214\174\376\006\202\265\311"
  "\300\236\250\171\374\156\173\204\311\325\034\162\027\115\155\046"
  "\247\225\130\153\023\373\352\200\362\256\177\250\371\030\362\361"
  "\061\332\041\140\061\203\333\006\237\372\316\264\304\224\216\042"
  "\214\270\215\276\050\302\125\121\013\305\156\172\205\044\016\344"
  "\353\063\113\326\003\231\173\276\313\037\310\016\204\353\367\005"
  "\155\220\057\220\057\075\241\010\317\103\206\275\072\173\137\371"
  "\057\200\310\031\021\351\073\324\136\127\115\236\170\136\163\004"
  "\014\074\341\123\333\327\004\222\237\057\142\025\051\035\161\206"
  "\172\041\044\072\266\044\066\117\041\273\056\127\177\127\270\204"
  "\350\261\036\144\211\015\377\010\211\221\000\115\257\042\002\123"
  "\230\317\343\055\014\065\314\042\244\063\357\275\160\206\122\333"
  "\150\157\265\134\343\164\220\323\312\264\124\231\313\257\073\032"
  "\042\313\372\213\374\363\276\261\145\233\064\346\351\025\046\134"
  "\221\275\057\140\132\267\042\060\247\302\230\266\312\303\236\266"
  "\005\073\104\327\367\203\154\353\326\025\331\146\362\211\203\175"
  "\072\240\214\372\163\100\267\001\272\155\077\350\266\155\154\167"
  "\344\010\267\147\323\003\050\067\100\271\035\014\345\126\342\035"
  "\262\145\140\152\072\155\075\017\004\113\117\302\233\140\306\244"
  "\063\041\037\350\342\017\345\136\174\346\076\171\263\362\066\320"
  "\375\230\170\004\205\172\001\115\360\034\231\130\270\023\310\343"
  "\023\202\260\343\060\231\173\120\337\371\034\015\310\030\077\022"
  "\104\155\223\273\256\230\136\066\177\205\044\205\071\302\256\040"
  "\142\263\071\032\023\361\227\370\251\350\000\237\241\071\237\312"
  "\207\031\167\037\304\117\370\324\266\220\051\106\201\251\375\234"
  "\266\340\150\044\307\047\036\355\021\362\346\236\117\046\242\305"
  "\061\366\221\340\167\271\220\026\035\016\005\151\333\107\076\161"
  "\047\324\306\054\350\015\345\356\053\065\234\345\060\117\227\243"
  "\057\162\032\072\253\073\025\105\147\346\342\202\024\012\147\220"
  "\026\136\335\371\253\156\257\331\273\150\266\172\355\213\116\367"
  "\254\165\321\041\047\315\327\107\213\221\212\130\053\152\371\265"
  "\052\100\042\243\301\122\003\223\223\201\314\020\332\243\023\205"
  "\002\036\360\047\235\013\221\030\327\213\141\243\007\241\166\344"
  "\316\041\224\206\126\005\111\240\146\110\005\244\313\042\214\370"
  "\107\046\132\267\152\314\040\127\200\120\052\131\256\326\021\000"
  "\141\071\076\127\130\235\176\146\347\064\043\103\177\223\215\240"
  "\233\365\106\320\027\147\151\315\336\006\040\037\050\357\120\242"
  "\364\002\356\250\074\134\137\304\021\257\140\133\062\302\155\251"
  "\316\373\320\372\301\254\327\207\075\230\325\152\303\311\054\250"
  "\000\231\137\050\227\236\230\156\162\171\161\140\271\354\200\134"
  "\002\206\106\177\144\113\107\107\144\313\063\253\033\052\047\351"
  "\012\120\351\125\254\162\122\015\040\010\111\005\224\326\272\277"
  "\037\264\111\257\246\150\223\116\125\127\167\137\260\213\042\220"
  "\211\007\062\017\055\125\257\016\200\211\345\271\212\074\215\077"
  "\026\171\171\307\120\215\270\112\273\051\026\250\262\246\201\334"
  "\271\034\154\131\371\201\001\001\074\242\040\021\265\375\056\111"
  "\344\203\214\050\254\110\326\176\344\360\051\003\200\041\261\176"
  "\210\045\347\263\360\240\124\370\231\061\123\037\246\344\210\252"
  "\107\051\275\061\226\203\221\333\174\343\222\332\273\166\057\357"
  "\135\102\376\116\111\070\245\276\170\062\036\305\143\206\311\054"
  "\155\102\113\234\324\065\173\211\312\174\210\215\331\211\172\024"
  "\363\253\252\070\154\057\374\224\064\141\375\045\215\345\254\311"
  "\111\073\131\321\076\115\321\277\323\164\113\226\352\304\115\051"
  "\236\164\115\174\301\072\253\376\112\340\343\122\270\246\277\257"
  "\246\030\034\323\052\071\246\331\314\332\210\254\242\311\010\166"
  "\327\104\250\221\301\314\213\366\310\044\101\264\142\230\314\326"
  "\147\111\166\163\236\327\067\123\202\333\251\100\345\350\214\376"
  "\363\131\245\342\037\311\233\107\305\243\037\153\152\171\077\261"
  "\217\263\003\307\076\242\306\022\075\216\227\235\111\205\001\177"
  "\371\122\320\373\244\265\216\237\252\030\031\214\030\353\213\161"
  "\076\037\343\263\057\337\142\145\116\236\004\367\156\055\263\051"
  "\317\077\106\056\361\034\156\173\242\067\315\306\145\250\346\147"
  "\364\047\166\055\241\355\271\034\375\263\337\057\332\331\244\275"
  "\352\311\333\123\145\067\017\261\111\056\377\360\377\075\356\275"
  "\007\000\050\165\165\141\171\051" };

static GStaticResource static_resource = { glade_resources_resource_data.data, sizeof (glade_resources_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *glade_resources_get_resource (void);
GResource *glade_resources_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/* GLIB - Library of useful routines for C programming
 * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GLib Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GLib at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_CONSTRUCTOR_H__
#define __G_CONSTRUCTOR_H__

/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER)

/*
 * Only try to include gslist.h if not already included via glib.h,
 * so that items using gconstructor.h outside of GLib (such as
 * GResources) continue to build properly.
 */
#ifndef __G_LIB_H__
#include "gslist.h"
#endif

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */
#endif /* __G_CONSTRUCTOR_H__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(glade_resourcesresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(glade_resourcesresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(glade_resourcesresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(glade_resourcesresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void glade_resourcesresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void glade_resourcesresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
